==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/it.php <==
<?php

return [
    'Names' => [
        'Afak' => 'afaka',
        'Aghb' => 'albanese caucasico',
        'Arab' => 'arabo',
        'Aran' => 'nastaliq',
        'Armi' => 'aramaico imperiale',
        'Armn' => 'armeno',
        'Avst' => 'avestico',
        'Bali' => 'balinese',
        'Bamu' => 'bamum',
        'Bass' => 'Bassa Vah',
        'Batk' => 'batak',
        'Beng' => 'bengalese',
        'Blis' => 'simboli bliss',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'braille',
        'Bugi' => 'buginese',
        'Buhd' => 'buhid',
        'Cakm' => 'chakma',
        'Cans' => 'simboli aborigeni canadesi unificati',
        'Cari' => 'carian',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Cirt' => 'cirth',
        'Copt' => 'copto',
        'Cprt' => 'cipriota',
        'Cyrl' => 'cirillico',
        'Cyrs' => 'cirillico antica chiesa slavonica',
        'Deva' => 'devanagari',
        'Dsrt' => 'deseret',
        'Dupl' => 'stenografia duployan',
        'Egyd' => 'egiziano demotico',
        'Egyh' => 'ieratico egiziano',
        'Egyp' => 'geroglifici egiziani',
        'Ethi' => 'etiope',
        'Geok' => 'kutsuri',
        'Geor' => 'georgiano',
        'Glag' => 'glagolitico',
        'Goth' => 'gotico',
        'Gran' => 'grantha',
        'Grek' => 'greco',
        'Gujr' => 'gujarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'han, bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoo',
        'Hans' => 'semplificato',
        'Hant' => 'tradizionale',
        'Hebr' => 'ebraico',
        'Hira' => 'hiragana',
        'Hluw' => 'geroglifici anatolici',
        'Hmng' => 'pahawn hmong',
        'Hrkt' => 'katanaka o hiragana',
        'Hung' => 'antico ungherese',
        'Inds' => 'indu',
        'Ital' => 'italico antico',
        'Jamo' => 'jamo',
        'Java' => 'javanese',
        'Jpan' => 'giapponese',
        'Jurc' => 'jurchen',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'kharoshthi',
        'Khmr' => 'khmer',
        'Khoj' => 'khojki',
        'Knda' => 'kannada',
        'Kore' => 'coreano',
        'Kpel' => 'Kpelle',
        'Kthi' => 'kaithi',
        'Lana' => 'lanna',
        'Laoo' => 'lao',
        'Latf' => 'variante fraktur del latino',
        'Latg' => 'variante gaelica del latino',
        'Latn' => 'latino',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lina' => 'lineare A',
        'Linb' => 'lineare B',
        'Lisu' => 'lisu',
        'Loma' => 'loma',
        'Lyci' => 'lyci',
        'Lydi' => 'lydi',
        'Mand' => 'mandaico',
        'Mani' => 'manicheo',
        'Maya' => 'geroglifici maya',
        'Mend' => 'mende',
        'Merc' => 'corsivo meroitico',
        'Mero' => 'meroitico',
        'Mlym' => 'malayalam',
        'Mong' => 'mongolo',
        'Moon' => 'moon',
        'Mroo' => 'mro',
        'Mtei' => 'meetei mayek',
        'Mymr' => 'birmano',
        'Narb' => 'arabo settentrionale antico',
        'Nbat' => 'nabateo',
        'Nkgb' => 'geba naxi',
        'Nkoo' => 'n’ko',
        'Nshu' => 'nushu',
        'Ogam' => 'ogham',
        'Olck' => 'ol chiki',
        'Orkh' => 'orkhon',
        'Orya' => 'oriya',
        'Osma' => 'osmanya',
        'Palm' => 'palmireno',
        'Perm' => 'permico antico',
        'Phag' => 'phags-pa',
        'Phli' => 'pahlavi delle iscrizioni',
        'Phlp' => 'pahlavi psalter',
        'Phlv' => 'pahlavi book',
        'Phnx' => 'fenicio',
        'Plrd' => 'fonetica di pollard',
        'Prti' => 'partico delle iscrizioni',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Roro' => 'rongorongo',
        'Runr' => 'runico',
        'Samr' => 'samaritano',
        'Sara' => 'sarati',
        'Sarb' => 'arabo meridionale antico',
        'Saur' => 'saurashtra',
        'Sgnw' => 'linguaggio dei segni',
        'Shaw' => 'shaviano',
        'Shrd' => 'sharada',
        'Sind' => 'khudawadi',
        'Sinh' => 'singalese',
        'Sora' => 'sora sompeng',
        'Sund' => 'sundanese',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'siriano',
        'Syre' => 'siriaco estrangelo',
        'Syrj' => 'siriaco occidentale',
        'Syrn' => 'siriaco orientale',
        'Tagb' => 'tagbanwa',
        'Takr' => 'takri',
        'Tale' => 'tai le',
        'Talu' => 'tai lue',
        'Taml' => 'tamil',
        'Tang' => 'tangut',
        'Tavt' => 'tai viet',
        'Telu' => 'telugu',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagalog',
        'Thaa' => 'thaana',
        'Thai' => 'thailandese',
        'Tibt' => 'tibetano',
        'Tirh' => 'tirhuta',
        'Ugar' => 'ugarita',
        'Vaii' => 'vaii',
        'Visp' => 'alfabeto visivo',
        'Wara' => 'varang kshiti',
        'Wole' => 'woleai',
        'Xpeo' => 'persiano antico',
        'Xsux' => 'sumero-accadiano cuneiforme',
        'Yiii' => 'yi',
        'Zinh' => 'ereditato',
        'Zmth' => 'notazione matematica',
        'Zsye' => 'emoji',
        'Zsym' => 'simboli',
        'Zxxx' => 'non scritto',
        'Zyyy' => 'comune',
    ],
];

==> symfony_8.0.0+dfsg.orig.tar.xz: symfony-8.0.0/src/Symfony/Component/Intl/Resources/data/scripts/it.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Afak' => 'afaka',
        'Aghb' => 'albanese caucasico',
        'Arab' => 'arabo',
        'Aran' => 'nastaliq',
        'Armi' => 'aramaico imperiale',
        'Armn' => 'armeno',
        'Avst' => 'avestico',
        'Bali' => 'balinese',
        'Bamu' => 'bamum',
        'Bass' => 'Bassa Vah',
        'Batk' => 'batak',
        'Beng' => 'bengalese',
        'Blis' => 'simboli bliss',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'braille',
        'Bugi' => 'buginese',
        'Buhd' => 'buhid',
        'Cakm' => 'chakma',
        'Cans' => 'sillabario aborigeno canadese unificato',
        'Cari' => 'carian',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Cirt' => 'cirth',
        'Copt' => 'copto',
        'Cprt' => 'cipriota',
        'Cyrl' => 'cirillico',
        'Cyrs' => 'cirillico antica chiesa slavonica',
        'Deva' => 'devanagari',
        'Dsrt' => 'deseret',
        'Dupl' => 'stenografia duployan',
        'Egyd' => 'egiziano demotico',
        'Egyh' => 'ieratico egiziano',
        'Egyp' => 'geroglifici egiziani',
        'Ethi' => 'etiope',
        'Geok' => 'kutsuri',
        'Geor' => 'georgiano',
        'Glag' => 'glagolitico',
        'Goth' => 'gotico',
        'Gran' => 'grantha',
        'Grek' => 'greco',
        'Gujr' => 'gujarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'han, bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoo',
        'Hans' => 'semplificato',
        'Hant' => 'tradizionale',
        'Hebr' => 'ebraico',
        'Hira' => 'hiragana',
        'Hluw' => 'geroglifici anatolici',
        'Hmng' => 'pahawn hmong',
        'Hrkt' => 'katanaka o hiragana',
        'Hung' => 'antico ungherese',
        'Inds' => 'indu',
        'Ital' => 'italico antico',
        'Jamo' => 'jamo',
        'Java' => 'javanese',
        'Jpan' => 'giapponese',
        'Jurc' => 'jurchen',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'kharoshthi',
        'Khmr' => 'khmer',
        'Khoj' => 'khojki',
        'Knda' => 'kannada',
        'Kore' => 'coreano',
        'Kpel' => 'Kpelle',
        'Kthi' => 'kaithi',
        'Lana' => 'lanna',
        'Laoo' => 'lao',
        'Latf' => 'variante fraktur del latino',
        'Latg' => 'variante gaelica del latino',
        'Latn' => 'latino',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lina' => 'lineare A',
        'Linb' => 'lineare B',
        'Lisu' => 'lisu',
        'Loma' => 'loma',
        'Lyci' => 'lyci',
        'Lydi' => 'lydi',
        'Mand' => 'mandaico',
        'Mani' => 'manicheo',
        'Maya' => 'geroglifici maya',
        'Mend' => 'mende',
        'Merc' => 'corsivo meroitico',
        'Mero' => 'meroitico',
        'Mlym' => 'malayalam',
        'Mong' => 'mongolo',
        'Moon' => 'moon',
        'Mroo' => 'mro',
        'Mtei' => 'meetei mayek',
        'Mymr' => 'birmano',
        'Narb' => 'arabo settentrionale antico',
        'Nbat' => 'nabateo',
        'Nkgb' => 'geba naxi',
        'Nkoo' => 'n’ko',
        'Nshu' => 'nushu',
        'Ogam' => 'ogham',
        'Olck' => 'ol chiki',
        'Orkh' => 'orkhon',
        'Orya' => 'oriya',
        'Osma' => 'osmanya',
        'Palm' => 'palmireno',
        'Perm' => 'permico antico',
        'Phag' => 'phags-pa',
        'Phli' => 'pahlavi delle iscrizioni',
        'Phlp' => 'pahlavi psalter',
        'Phlv' => 'pahlavi book',
        'Phnx' => 'fenicio',
        'Plrd' => 'fonetica di pollard',
        'Prti' => 'partico delle iscrizioni',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Rohg' => 'hanifi',
        'Roro' => 'rongorongo',
        'Runr' => 'runico',
        'Samr' => 'samaritano',
        'Sara' => 'sarati',
        'Sarb' => 'arabo meridionale antico',
        'Saur' => 'saurashtra',
        'Sgnw' => 'linguaggio dei segni',
        'Shaw' => 'shaviano',
        'Shrd' => 'sharada',
        'Sind' => 'khudawadi',
        'Sinh' => 'singalese',
        'Sora' => 'sora sompeng',
        'Sund' => 'sundanese',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'siriaco',
        'Syre' => 'siriaco estrangelo',
        'Syrj' => 'siriaco occidentale',
        'Syrn' => 'siriaco orientale',
        'Tagb' => 'tagbanwa',
        'Takr' => 'takri',
        'Tale' => 'tai le',
        'Talu' => 'tai lue',
        'Taml' => 'tamil',
        'Tang' => 'tangut',
        'Tavt' => 'tai viet',
        'Telu' => 'telugu',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagalog',
        'Thaa' => 'thaana',
        'Thai' => 'thailandese',
        'Tibt' => 'tibetano',
        'Tirh' => 'tirhuta',
        'Ugar' => 'ugarita',
        'Vaii' => 'vai',
        'Visp' => 'alfabeto visivo',
        'Wara' => 'varang kshiti',
        'Wole' => 'woleai',
        'Xpeo' => 'persiano antico',
        'Xsux' => 'sumero-accadiano cuneiforme',
        'Yiii' => 'yi',
        'Zinh' => 'ereditato',
        'Zmth' => 'notazione matematica',
        'Zsye' => 'emoji',
        'Zsym' => 'simboli',
        'Zxxx' => 'non scritto',
        'Zyyy' => 'comune',
    ],
];
